====================================
Functions for generating Rank Tables
====================================

.. automodule:: abed.results.ranks
    :members:
    :undoc-members:
    :show-inheritance:
